pub struct CollisionPoint {
pub world_a: Vec3,
pub world_b: Vec3,
pub local_a: Vec3,
pub local_b: Vec3,
pub normal: Vec3,
pub distance: f32,
}Fields
world_a: Vec3Position of the contact on the first object in world space.
world_b: Vec3Position of the contact on the second object in world space;
local_a: Vec3Position of the contact on the first object in local space.
local_b: Vec3Position of the contact on the second object in local space.
normal: Vec3Contact normal, pointing towards the exterior of the first shape.
distance: f32Contact normal, pointing towards the exterior of the second shape. Distance between the two contact points.
If this is negative, this contact represents a penetration.